
#import <Foundation/Foundation.h>
#import <AliRTCSdk/AliRtcEngine.h>
#import <AliyunPlayer/AliPlayer.h>
#import <AliyunPlayer/AliPlayerGlobalSettings.h>

NS_ASSUME_NONNULL_BEGIN

@interface AliRtcPlayerExtension : NSObject

/**
 * @brief 初始化AliRtcPlayerExtension
 */
+ (instancetype)shareInstance;

/**
 * @brief 将播放器关键错误日志，及Event Report日志，合并到RTC引擎。
 * @note 如果app自己有存储播放器的日志做问题定位，则不需要调用此接口。
 */
+ (void)enablePlayerLogger:(BOOL)enable;

/**
 * @brief 关联播放器和RTC引擎
 * @param player 播放器实例
 * @param engine RTC引擎实例
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)bindPlayerToRtcEngine:(AliPlayer *)player engine:(AliRtcEngine *)engine;

/**
 * @brief 取消播放器和RTC引擎的关联
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)unbindPlayerFromRtcEngine;

/**
 * @brief 启动推送播放器音频流到频道
 * @param onlyLocalPlay 是否只在本地播放；YES表示只在本地播放，不推送到远端
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)publishAudio:(BOOL)onlyLocalPlay;

/**
 * @brief 停止推送播放器音频流到频道
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)unpublishAudio;

/**
 * @brief 启动推送播放器视频流到频道
 * @param type 流类型，建议AliRtcVideosourceScreenShareType
 * @param renderMode 输入视频比例和推流profile不一致时，按照设置的renderMode进行对应处理
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)publishVideo:(AliRtcVideoSource)type renderMode:(AliRtcRenderMode)renderMode;

/**
 * @brief 停止推送播放器视频流到频道
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)unpublishVideo;

/**
 * @brief 设置外部输入音频的推流混音音量
 * @param volume 音量 0-100
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)setExternalAudioPublishVolume:(int)volume;

/**
 * @brief 设置外部输入音频的播放混音音量
 * @param volume 音量 0-100
 * @return 返回0表示成功，返回负数表示失败。
 */
- (int)setExternalAudioPlayoutVolume:(int)volume;

@end

NS_ASSUME_NONNULL_END
